@@ -399,8 +399,9 @@ def eval_sexp(sexp, env):
                 for exp in sexp[1:]:
                     res = eval_sexp(exp, env)
                 return res
+        # ns stuff #
         elif is_s and "ns" == head.name:
-            ns_name = sexp.positional[1].name                
+            ns_name = sexp.positional[1].name           
             if ns_name not in loaded_ns:
                 if env.ns.name == "":
                     # it means the execution is not currently happening in an environment:
@@ -416,12 +417,21 @@ def eval_sexp(sexp, env):
             # requires/refers other namespaces and vars as specified
             # dadi
             break
+        elif is_s and "in-ns" == head.name:
+            ns_name = sexp.positional[1][1].name
+            if ns_name not in loaded_ns:
+                eval_sexp(read_sexp(f"(ns {ns_name})"), env)
+            else:
+                # this doesn't seem to work
+                env = loaded_ns[ns_name]
+            break
         elif is_s and "require" == head.name:
             require([sexp.positional[1].name], env.ns)
             break
         elif is_s and "include" == head.name:
             require([sexp.positional[1].name], env.ns, include=True)
             break
+        # macros #
         elif is_s and "quasiquote" == head.name:
             sexp = quasiquote(sexp[1])
             continue # TCO
